@@ -1,8 +1,8 @@
 
-__version__ = "0.5.3"
+__version__ = "0.6"
 __version_vcs_info__ = {
-    'branch': 'hotfix-0.5.3',
-    'revid': 'dc0ecb2',
-    'revno': 402}
+    'branch': 'master',
+    'revid': '37d1ea1',
+    'revno': 426}
 __version_user_email__ = "skalkoto@grnet.gr"
 __version_user_name__ = "Nikos Skalkotos"
